@@ -6,9 +6,10 @@ function (x, labels = c ("cluster", "observation"), text, main, sub, xlab, ylab,
     stop ("dataset not included in tclust object - cannot plot object.")
   
   if (missing (sub))
-    sub <- paste ("k = ", x$k, #" (", x$par$k, "), 
-            ", alpha = ", x$par$alpha, #", obj = ", round (x$obj, 2), 
-            sep = "")
+    sub <- bquote(paste (k == .(x$par$k), ", ", alpha == .(x$par$alpha)))
+#     sub <- paste ("k = ", x$k, #" (", x$par$k, "), 
+#             ", alpha = ", x$par$alpha, #", obj = ", round (x$obj, 2), 
+#             sep = "")
 
   if (by.cluster)
   {
