@@ -140,6 +140,9 @@
 
 	void ColSumWeighted (const IMatD &m, const IVecD &v, IVecD &s) ;
 
+	DWORD which_max_abs (const IVecD &v) ;
+	DWORD first_idx_NZ (const IVecD &v, double dZeroTol = 1e-16) ;
+
 	inline void colMeans (const IMatD &A, const IVecD &vec)	{ iter_col (A, vec, mean) ; }
 	inline void rowMeans (const IMatD &A, const IVecD &vec)	{ iter_row (A, vec, mean) ; }
 	inline  IVecD colMeans (const IMatD &A) { IVecD v (A.ncol ()) ; colMeans (A, v) ; return v ; }
